pub struct ResultState(pub String);Expand description
A status an operation is allowed to answer with.
An operation that needs a state outside this set is not conformant; the contract must be versioned first. This is the rule that keeps two implementations answerable to one client.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ResultState
impl Clone for ResultState
Sourcefn clone(&self) -> ResultState
fn clone(&self) -> ResultState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResultState
impl Debug for ResultState
impl Eq for ResultState
Sourceimpl Ord for ResultState
impl Ord for ResultState
Sourcefn cmp(&self, other: &ResultState) -> Ordering
fn cmp(&self, other: &ResultState) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ResultState
impl PartialEq for ResultState
Sourceimpl PartialOrd for ResultState
impl PartialOrd for ResultState
impl StructuralPartialEq for ResultState